# Generated by Django 4.0 on 2021-12-19 18:56

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('sites', '0002_alter_domain_unique'),
    ]

    operations = [
        migrations.CreateModel(
            name='FlatPage',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('url', models.CharField(db_index=True, max_length=100, verbose_name='URL')),
                ('title', models.CharField(max_length=200, verbose_name='title')),
                ('content', models.TextField(blank=True, verbose_name='content')),
                ('enable_comments', models.BooleanField(default=False, verbose_name='enable comments')),
                ('meta', models.TextField(blank=True, help_text='Example: <code>&#60;meta name="viewport" content="width=device-width, initial-scale=1"&#62;<br/>&#60;meta name="something else" content="something else goes here"&#62;</code>.')),
                ('template_name', models.CharField(blank=True, help_text='Example: “betterFlatPages/contact_page.html”. If this isn’t provided, the system will use “betterFlatPages/default.html”.', max_length=70, verbose_name='template name')),
                ('registration_required', models.BooleanField(default=False, help_text='If this is checked, only logged-in users will be able to view the page.', verbose_name='registration required')),
                ('sites', models.ManyToManyField(to='sites.Site', verbose_name='sites')),
            ],
            options={
                'verbose_name': 'flat page',
                'verbose_name_plural': 'flat pages',
                'ordering': ['url'],
            },
        ),
    ]
